from passenger import Passenger

# INSERT YOUR CODE AFTER THIS LINE

class Flight:
  """Flight class"""
  def __init__(self, flight_no, passengers=[]):
    """Constructor"""
    if not isinstance(flight_no, int):
      raise Exception("flight_no must be an integer")
    if not isinstance(passengers, list):
      raise Exception("passengers must be a list")
    self.flight_no = flight_no
    self.passengers = passengers
    self.__do_sort_passengers()
    
  def add_passenger(self, passenger):
    """Adds a passenger"""
    if not isinstance(passenger, Passenger):
      raise Exception("passenger must be a Passenger object")
    self.passengers.append(passenger)
    self.__do_sort_passengers()

  def __str__(self):
    """ToString method"""
    return "Flight No. " + str(self.flight_no) + "\n" + '\n'.join(["%s" % p for p in self.passengers])
    
  def heaviest_passenger(self):
    return self.passengers[len(self.passengers) - 1]
    
  def lightest_passenger(self):
    return self.passengers[0]
    
  def __do_sort_passengers(self):
    self.passengers.sort(key=lambda x: sum(x.suitcase_weights))

# INSERT YOUR CODE BEFORE THIS LINE

# And here's some code to test out your implementation.  You can change this if you'd like.
if __name__ == "__main__":
  f = Flight(1)
  p1 = Passenger('Amelia', [5.2,1.2,8.2,1.0], 'business')
  f.add_passenger(p1)
  print f
  
  p2 = Passenger('Harvey', [9.1,29.2,3.2,1.7], 'economy')
  f.add_passenger(p2)
  print f

  print "Heaviest passenger: "
  print f.heaviest_passenger()

  print "Lightest passenger: "
  print f.lightest_passenger()
